@@ -1,5 +1,6 @@
 ORmn1 = function(y1, n1, y2, n2, conf.level=0.95)
 {
+  if (length(y1) > 1) stop("This does not support multiple strata!")
   if (any(c(y1, n1 - y1, y2, n2 - y2) < 0) | any(c(n1, n2) == 0)) stop("Check the input!")
   if (any(c(n1 - y1, n2 - y2) == 0)) stop("Check the input!")
   p1 = y1/n1
@@ -10,15 +11,21 @@ ORmn1 = function(y1, n1, y2, n2, conf.level=0.95)
   v0 = qchisq(conf.level, 1) # delta ofv for confidence interval
 
   Obj = function(or) {  # find or points of increased obj fx value (ofv) by v0
-    mLL = function(p2d) {
-      p1d = p2d*or/(1 + p2d*(or - 1))
-      -(log(dbinom(y1, n1, p1d)) + log(dbinom(y2, n2, p2d)))
-    }
-    p2d = nlminb(p2, mLL, lower=0, upper=1)$par
-    p1d = p2d*or/(1 + p2d*(or - 1))   # MLE p1d, p2d with fixed odds ratio or
-    div = (p1 - p1d)/(p1d*(1 - p1d)) - (p2 - p2d)/(p2d*(1 - p2d))
-    var0 = (1/(n1*p1d*(1 - p1d)) + 1/(n2*p2d*(1 - p2d)))*(n1 + n2)/(n1 + n2 - 1)
-    return((div^2/var0 - v0)^2)       # find the root of increased ofv by v0
+#    mLL = function(p2d) {
+#      p1d = p2d*or/(1 + p2d*(or - 1))
+#      -(log(dbinom(y1, n1, p1d)) + log(dbinom(y2, n2, p2d)))
+#    }
+#    p2d = nlminb(p2, mLL, lower=0, upper=1)$par
+#    p1d = p2d*or/(1 + p2d*(or - 1))   # MLE p1d, p2d with fixed odds ratio or
+    A = n2*(or - 1)                         # eq 13
+    B = n1*or + n2 - (y1 + y2)*(or - 1)
+    C1 = -(y1 + y2)
+    p2t = (-B + sqrt(B*B - 4*A*C1))/(2*A)
+    p1t = p2t*or/(1 + p2t*(or - 1))
+
+    nume = (p1 - p1t)/(p1t*(1 - p1t)) - (p2 - p2t)/(p2t*(1 - p2t))
+    var0 = (1/(n1*p1t*(1 - p1t)) + 1/(n2*p2t*(1 - p2t)))*(n1 + n2)/(n1 + n2 - 1)
+    return((nume^2/var0 - v0)^2)       # find the root of increased ofv by v0
   }
 
   options(warn=-1)
